Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1042)

Unified Diff: public/web/WebNodeList.h

Issue 152243003: Rename WebNodeCollection to WebElementCollection for clarity (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « public/web/WebNodeCollection.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/web/WebNodeList.h
diff --git a/public/web/WebNodeList.h b/public/web/WebNodeList.h
index 14271f65340a175ca8ef04a36170a63ca8e8b546..c2038d8fbd72fce990ca882c6847d5d4c7c71f4c 100644
--- a/public/web/WebNodeList.h
+++ b/public/web/WebNodeList.h
@@ -32,7 +32,7 @@
#define WebNodeList_h
#include "../platform/WebCommon.h"
-#include "WebNodeCollection.h"
+#include "WebElementCollection.h"
namespace WebCore { class NodeList; }
#if BLINK_IMPLEMENTATION
@@ -56,8 +56,8 @@ public:
}
// FIXME(crbug.com/235008): Remove once chromium has been updated to stop using
- // WebCollection as a WebNodeList.
- BLINK_EXPORT WebNodeList(const WebNodeCollection&);
+ // WebElementCollection as a WebNodeList.
+ BLINK_EXPORT WebNodeList(const WebElementCollection&);
BLINK_EXPORT void reset();
BLINK_EXPORT void assign(const WebNodeList&);
« no previous file with comments | « public/web/WebNodeCollection.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698